@@ -1,13 +1,13 @@
+use super::file_attrs::{FileAttrs, FileAttrsBox};
 use super::{
-    constants, extensions::Extensions, file_attrs::FileAttrs, seq_iter::SeqIter,
-    visitor::impl_visitor, HandleOwned,
+    constants, extensions::Extensions, seq_iter::SeqIter, visitor::impl_visitor, HandleOwned,
 };
 
 use serde::de::{Deserializer, Error, Unexpected};
 use serde::Deserialize;
 use ssh_format::from_bytes;
 
-use vec_strings::StringsNoIndex;
+use vec_strings::{StringsNoIndex, TwoStrs};
 
 #[derive(Debug, Clone)]
 pub struct ServerVersion {
@@ -51,13 +51,11 @@ pub enum ResponseInner {
 
     Handle(HandleOwned),
 
-    /// The remaining bytes returned by ssh_format::from_bytes is the data
-    /// of the packet.
     Data,
 
     Name(Box<[NameEntry]>),
 
-    Attrs(FileAttrs),
+    Attrs(FileAttrsBox),
 }
 
 #[derive(Debug, Clone)]
@@ -196,16 +194,20 @@ impl<'de> Deserialize<'de> for StatusCode {
 }
 
 #[derive(Debug, Clone, Deserialize)]
-pub struct ErrMsg {
-    pub err_msg: Box<str>,
+pub struct ErrMsg(TwoStrs);
 
-    /// [RFC-1766]
+impl ErrMsg {
+    /// Returns (err_message, language_tag).
     ///
-    /// This tag can be parsed by
+    /// Language tag is defined according to specification [RFC-1766].
+    ///
+    /// It can be parsed by
     /// [pyfisch/rust-language-tags](https://github.com/pyfisch/rust-language-tags)
     /// according to
     /// [this issue](https://github.com/pyfisch/rust-language-tags/issues/39).
-    pub language_tag: Box<str>,
+    pub fn get(&self) -> (&str, &str) {
+        self.0.get()
+    }
 }
 
 /// Entry in ResponseInner::Name
